@@ -12,3 +12,6 @@
 
 /* Define if you have IPv6 */
 #undef HAVE_IPV6
+
+/* Define if you have BSD syslog without facilities */
+#undef HAVE_OLD_SYSLOG
