@@ -459,7 +459,7 @@ static int getbody( struct newsgroup* group, int id ) {
     fclose( g );
 
     /* create a whole bunch of new hardlinks */
-    store( c, f, 0, newsgroups, "", "", "", messageid, "", "" );
+    store( c, f, newsgroups, messageid );
 
     /* retrieve body */
     fprintf( f, "\n" ); /* Empty line between header and body. */
@@ -561,9 +561,9 @@ static void getmarked( struct newsgroup* group ) {
  */
 int getgroup ( struct newsgroup * g, int server ) {
     static char *hd[10];
-    char *hnames[10] = {"Path: ", "Message-ID: ", "From: ", "Newsgroups: ",
-			"Subject: ", "Date: ", "References: ", "Lines: ", 
-			"Xref: ", ""};
+    const char *hnames[10] = {"Path: ", "Message-ID: ", "From: ", 
+			"Newsgroups: ", "Subject: ", "Date: ", 
+			"References: ", "Lines: ", "Xref: ", ""};
     int fetched, killed;
     int h;
     int n;
@@ -660,11 +660,9 @@ int getgroup ( struct newsgroup * g, int server ) {
 	     ( now-st.st_ctime > (timeout_long * SECONDS_PER_DAY) ) ) {
 	    if ( verbose > 1 )
 		printf("skipping %s from now on\n", g->name);
-	    syslog( LOG_INFO, "skip %s (%d): %d, %d", g->name, (int)now,
-		    (int)now-st.st_ctime, (int)now-st.st_mtime );
+	    syslog( LOG_INFO, "skip %s (%d): %ld, %ld", g->name, (int)now,
+		    (long)now-st.st_ctime, (long)now-st.st_mtime );
 	    unlink(s);
-	    g->first = 1;
-	    g->last = 1;
 	    return server ;
        }
     }
@@ -1003,13 +1001,8 @@ int getgroup ( struct newsgroup * g, int server ) {
 	    h++;
 	}
 	/* generate hardlinks; this procedure also increments g->last */
-	store( c, f, st.st_size, *hd[3] ? hd[3]+strlen(hnames[3]) : "", 
-				 *hd[4] ? hd[4]+strlen(hnames[4]) : "", 
-				 *hd[2] ? hd[2]+strlen(hnames[2]) : "", 
-				 *hd[5] ? hd[5]+strlen(hnames[5]) : "", 
-				 *hd[1] ? hd[1]+strlen(hnames[1]) : "", 
-				 *hd[6] ? hd[6]+strlen(hnames[6]) : "", 
-				 *hd[7] ? hd[7]+strlen(hnames[7]) : "");
+	store( c, f, *hd[3] ? hd[3]+strlen(hnames[3]) : "", 
+				 *hd[1] ? hd[1]+strlen(hnames[1]) : "");
 
 	if ( delaybody ) {
 	    fclose( f );
@@ -1084,8 +1077,12 @@ static void nntpactive( time_t update ) {
     if ( active && !forceactive && ( stat( s, &st ) == 0 ) ) {
 	if ( verbose )
 	    printf( "Getting new newsgroups from %s\n", current_server->name );
-	strftime( timestr, 64, "%y%m%d %H%M00", gmtime( &update ) );
-	sprintf( lineout, "NEWGROUPS %s GMT\r\n", timestr );
+	/* to avoid a compiler warning we print out a four-digit year;
+	 * but since we need only the last two digits, we skip them
+	 * in the next line
+	 */
+	strftime( timestr, 64, "%Y%m%d %H%M00", gmtime( &update ) );
+	sprintf( lineout, "NEWGROUPS %s GMT\r\n", timestr+2 );
 	putaline();
 	if ( nntpreply() != 231 ) {
 	    printf( "Reading new newsgroups failed.\n" );
