@@ -18,6 +18,11 @@
 #define PATH_MAX MAXPATHLEN
 #endif
 
+#include <sys/types.h>  /* for regex.h */
+#include <regex.h> /* regex_t */
+#include <stdio.h> /* FILE * */
+#include <time.h>  /* time_t */
+
 #include "config.h"	/* FreeSGI barfs on #ifdef HAVE_CONFIG_H */
 
 #ifdef HAVE_AP_CONFIG_H
@@ -49,11 +54,6 @@ int snprintf( char *str, size_t n, const char *format, ... );
 #define LOG_CONS 0 /* if it isn't supported, make do without */
 #endif
 
-#include <sys/types.h>	/* for regex.h */
-#include <regex.h> /* regex_t */
-#include <stdio.h> /* FILE * */
-#include <time.h>  /* time_t */
-
 #define SECONDS_PER_DAY ( 24 * 60 * 60 )
 
 /* Limit on the number of message bodies marked for download per group. */
@@ -135,14 +135,8 @@ int dofilter( char * h ) ;
 void storearticle ( char * filename, char * msgid, char * newsgroups ) ;
 void store( const char * filename,
 	    FILE * filehandle,
-	    const size_t bytes,
-	    char * newsgroups,
-	    const char * subject,
-	    const char * from,
-	    const char * date,
-	    const char * msgid,
-	    const char * references,
-	    const char * lines);
+	    const char * newsgroups,
+	    const char * msgid);
 
 /*
  * find a certain header in an article and return it
@@ -160,8 +154,8 @@ struct xoverinfo {
 };
 
 extern struct xoverinfo * xoverinfo;
-extern long xfirst;
-extern long xlast;
+extern unsigned long xfirst;
+extern unsigned long xlast;
 
 int getxover( void );	/* set xoverinfo, return 0 on error, nonzero else */
 
@@ -250,7 +244,7 @@ char * critmalloc(size_t size, const char* message);
 char * critrealloc(char *a, size_t size, const char* message);
 int ngmatch(const char* pattern, const char* string);
 
-int rename(const char *old, const char *new);
+/* int rename(const char *old, const char *new); */
 				/* to avoid barfing of Digital Unix */
 
 /*
