@@ -51,7 +51,7 @@ extern struct state _res;
 
 /* xoverutil global vars */
 struct xoverinfo * xoverinfo;
-long xfirst, xlast;
+unsigned long xfirst, xlast;
 
 /* activutil global vars */
 struct newsgroup * active;
@@ -676,60 +676,6 @@ int snprintf( char *str, size_t n, const char *format, ... ) {
 
 #endif
 
-/*
- * Lars Wirzenius: read a line into memory, with no max length
- * return a pointer to the line, or NULL in case of error
- *
- * strip \r at EOL
- */
-char *getaline(FILE *f) {
-    static char *buf;       /* buffer for line */
-    static size_t size;     /* size of buffer */
-    size_t len;             /* # of chars stored into buf before '\0' */
-    char * p;
-    int i;
-
-    len = 0;
-    if (!size)
-	size = 256;
-    if (!buf)
-	buf = critmalloc( size, "reading line" );
-
-    while ((p=fgets(buf+len, size-len, f))) {
-	/* replace NUL bytes (which shouldn't be there anyway)
-	 * with spaces
-	 */
-	i = size - len;
-	while ( *p != '\n' && --i > 0 ) {
-	    if ( *p == '\0' )
-		*p = ' ';
-	    p++;
-	}
-	len += strlen(buf+len);
-	if ( buf[len-1] == '\n' )
-	    break;		/* the whole line has been read */
-
-	size += size;		/* exponential growth of buffer */
-	buf = critrealloc(buf, size, "reading line" );
-    }
-
-    if ( len == 0 )
-	return NULL;
-
-    if (len && (buf[len-1] == '\n')) { /* go back on top of the newline */
-	--len;
-	if (len && (buf[len-1] == '\r')) /* also delete CR */
-	    --len;
-    }
-
-    buf[len] = '\0';        /* unconditionally terminate string,
-                               possibly overwriting newline */
-
-    if ( debug )
-        syslog( LOG_DEBUG, "<%s\n", buf );
-    return buf;
-}
-
 int ngmatch(const char* pattern, const char* str) {
 #ifdef HAVE_FNMATCH
     if ( strchr( pattern, '?' ) || !strchr( pattern, '*' ) ||
