@@ -129,10 +129,13 @@ static time_t gmtoff( void ) {
     snprintf( oldzone, len, "TZ=%s", zone ? zone : "" );
     putenv( "TZ=GMT" );		/* use mktime to create UTC */
     gmtsec = mktime( ltime );
-    putenv( oldzone );
+    if ( !zone )
+	unsetenv( "TZ" );
+    else
+	putenv( oldzone );
     free( oldzone );
 
-    return( gmtsec - localsec );
+    return( localsec - gmtsec );
 }
 
 /*
@@ -543,13 +546,13 @@ void doarticle(const char *arg, int what) {
 void markinterest( void ) {
     struct stat st;
     struct utimbuf buf;
-    int error;
+    int err;
     time_t now;
     FILE * f;
 
     if ( !justaftergroup )
 	return;
-    error = 0;
+    err = 0;
     sprintf( s, "%s/interesting.groups/%s", spooldir, group->name );
     if ( stat( s, &st ) == 0 ) {
 	now = time(0);
@@ -557,11 +560,11 @@ void markinterest( void ) {
 			/* now < update may happen through HW failures */
 	buf.modtime = st.st_mtime;
 	if ( utime( s, &buf ) )
-	    error = 1;
+	    err = 1;
     }
     else
-	error = 1;
-    if ( error ) {
+	err = 1;
+    if ( err ) {
 	f = fopen( s, "w" );
 	if ( f )
 	    fclose( f );
@@ -916,10 +919,10 @@ void dopost( void ) {
 
     out = open( outname, O_WRONLY|O_EXCL|O_CREAT, 0444 );
     if ( out < 0 ) {
-	char *error = strerror(errno);
-	printf( "441 Unable to open spool file %s: %s\r\n", outname, error );
+	char *err = strerror(errno);
+	printf( "441 Unable to open spool file %s: %s\r\n", outname, err );
 	syslog( LOG_ERR, ">441 Unable to open spool file %s: %s",
-		outname, error );
+		outname, err );
 	return;
     }
 
@@ -1057,15 +1060,15 @@ void dopost( void ) {
 
 
 void doxhdr(char *arg) {
-    char * h[] = { "Subject", "From", "Date", "Message-ID", "References",
-		   "Bytes", "Lines"
-    };
+    const char * h[] = { "Subject", "From", "Date", "Message-ID",
+			 "References", "Bytes", "Lines" };
 
     int n = 7;
     int dash;
     char * l;
     char * buf;
-    int a,b=0,c;
+    unsigned int a,b=0;
+    unsigned int c;
 
     if ( !arg || !*arg ) {
 	if ( debugmode )
@@ -1170,7 +1173,7 @@ void doxhdr(char *arg) {
 
     dash = 0;
     if (l && isdigit((unsigned char)*l) ) {	/* handle range form */
-	a = strtol( l, &l, 10 );
+	a = strtoul( l, &l, 10 );
 	if ( a < xfirst )
 	    a = xfirst;
 	if (a && l && *l) {
@@ -1261,7 +1264,7 @@ void doxhdr(char *arg) {
 
 void doxover(const char *arg) {
     char * l;
-    int a,b, art;
+    unsigned int a,b, art;
 
     if (!group) {
 	printf( "412 Use the GROUP command first\r\n" );
@@ -1273,7 +1276,7 @@ void doxover(const char *arg) {
     markinterest();
 
     l = NULL;
-    b = a = strtol( arg, &l, 10 );
+    b = a = strtoul( arg, &l, 10 );
     if (a && l && *l) {
 	while (l && isspace((unsigned char)*l))
 	    l++;
@@ -1347,7 +1350,7 @@ void doxover(const char *arg) {
 
 void dolistgroup( const char * arg ) {
     struct newsgroup * g;
-    int art;
+    unsigned int art;
 
     if ( arg && strlen(arg) ) {
 	g = findgroup( arg );
@@ -1401,7 +1404,7 @@ void dolistgroup( const char * arg ) {
 
 
 
-int main( int argc, char ** argv ) {
+int main( void ) {
     int fodder;
     struct hostent *he;
 #ifdef HAVE_IPV6
