@@ -601,6 +601,13 @@ int main(int argc, char** argv)
 	exit( 2 );
     }
     readactive();
+    if ( !active ) {
+	printf( "Reading active file failed, exiting "
+		"(see syslog for more information).\n"
+		"Has fetchnews been run?\n" );
+	unlink( lockfile );
+	exit( 2 );
+    }
 
     if ( verbose ) {
 	printf( "texpire %s: ", version );
