@@ -172,7 +172,7 @@ int getxover( void ) {
     struct dirent * de;
     int fd;
     struct stat st;
-    long art;
+    unsigned long art;
     static char * overview;
     int error;
     char * p, * q;
@@ -338,6 +338,7 @@ int getxover( void ) {
 	if ( (wfd=open( mktemp(newfile), O_WRONLY|O_CREAT|O_EXCL, 0664 )) ) {
 #endif
 	    struct iovec oooh[UIO_MAXIOV];
+	    char lf[3];
 	    int vi, vc, va;
 
 	    vi = vc = va = 0;
@@ -347,7 +348,8 @@ int getxover( void ) {
 		    oooh[vi].iov_base = xoverinfo[art-xfirst].text;
 		    oooh[vi].iov_len = strlen( xoverinfo[art-xfirst].text );
 		    vc += oooh[vi++].iov_len + 1;
-		    oooh[vi].iov_base = "\n";
+		    strcpy(lf, "\n");
+		    oooh[vi].iov_base = lf;
 		    oooh[vi++].iov_len = 1;
 		    if ( vi >= (UIO_MAXIOV - 1) ) {
 			if ( writev( wfd, oooh, vi ) != vc ) {
